@@ -19,6 +19,7 @@ struct curve_s {
     void (*random)(point_ptr);
     void (*from_x)(point_ptr, element_ptr);
     void (*from_hash)(point_ptr, int, void *);
+    void (*neg)(point_ptr, point_ptr);
     void (*add)(point_ptr, point_ptr, point_ptr);
     void (*mul)(point_ptr, mpz_ptr, point_ptr);
     void (*curve_clear)(struct curve_s *curve);
@@ -57,6 +58,11 @@ static inline void point_from_hash(point_ptr p, int len, void *data)
     p->curve->from_hash(p, len, data);
 }
 
+static inline void point_neg(point_ptr r, point_ptr p)
+{
+    p->curve->neg(r, p);
+}
+
 static inline void point_add(point_ptr r, point_ptr p, point_ptr q)
 {
     r->curve->add(r, p, q);
