@@ -71,6 +71,8 @@ static int curve_group_from_bytes(element_t e, unsigned char *data)
     point_ptr P = e->data;
     int len;
 
+    //TODO: use point_set() instead of messing with internal data structure
+    P->inf_flag = 0;
     len = element_from_bytes(P->x, data);
     len += element_from_bytes(P->y, data + len);
     return len;
