@@ -3,6 +3,7 @@
 
 #include "curve.h"
 
+//for shoehorning the group of points on a curve into the `field' data type
 struct curve_group_data_s {
     curve_ptr curve;
     mpz_t cofac;
@@ -16,6 +17,7 @@ struct pairing_s {
     field_t G1, G2;
     field_ptr GT; //TODO replace with field_t?
 
+    void (*phi)(element_ptr out, element_ptr in, struct pairing_s *pairing); //isomorphism G2 --> G1
     void (*map)(element_ptr out, element_ptr in1, element_ptr in2,
 	    struct pairing_s *p);
     //is_almost coddh returns 1 given (g, g^x, h, h^x) or (g, g^x, h, h^-x)
@@ -34,6 +36,7 @@ struct mnt_pairing_data_s {
     field_t Fq, Fqx, Fqk;
     curve_t Eq, Eqk;
     mpz_t tateexp;
+    int k;
 };
 
 typedef struct mnt_pairing_data_s mnt_pairing_data_t[1];
