@@ -59,5 +59,21 @@ int main()
     element_out_str(stdout, 0, x);
     printf("\n");
 
+    {
+	int i;
+	int len = element_length_in_bytes(h);
+	printf("length_in_bytes(h) = %d\n", len);
+	unsigned char *data = malloc(len);
+	element_to_bytes(data, h);
+	for (i=0; i<len; i++) {
+	    printf(" %02X", data[i]);
+	    if (15 == (i % 16)) printf("\n");
+	}
+	printf("\n");
+	element_from_bytes(h, data);
+	printf("from_bytes h = ");
+	element_out_str(stdout, 0, h);
+	printf("\n");
+    }
     return 0;
 }
